@@ -23,18 +23,13 @@ from google.api_core import retry as retries
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
 
+from google.cloud.webrisk_v1 import gapic_version as package_version
 from google.cloud.webrisk_v1.types import webrisk
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-webrisk",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class WebRiskServiceTransport(abc.ABC):
@@ -48,7 +43,7 @@ class WebRiskServiceTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -174,7 +169,7 @@ class WebRiskServiceTransport(abc.ABC):
             ),
             self.create_submission: gapic_v1.method.wrap_method(
                 self.create_submission,
-                default_timeout=60.0,
+                default_timeout=600.0,
                 client_info=client_info,
             ),
         }
